@@ -3,12 +3,20 @@ from typing import Sequence, Tuple
 
 from django.contrib.admin.options import BaseModelAdmin
 from django.db import models
-from django.db.models import OuterRef, Subquery, functions
+from django.db.models import (
+    BooleanField,
+    ExpressionWrapper,
+    IntegerField,
+    OuterRef,
+    Q,
+    Subquery,
+    functions,
+)
 from django.db.models.functions import Cast
 from django.urls import reverse
 from django.utils.html import format_html
 
-from .query import (
+from .types import (
     BaseType,
     BooleanType,
     DateTimeType,
@@ -21,22 +29,9 @@ from .query import (
     YearType,
 )
 
-_OPEN_IN_ADMIN = "admin"
+OPEN_IN_ADMIN = "admin"
 
-
-_AGG_MAP = {
-    "average": lambda x: models.Avg(Cast(x, output_field=models.IntegerField())),
-    "count": lambda x: models.Count(x, distinct=True),
-    "max": models.Max,
-    "min": models.Min,
-    "std_dev": models.StdDev,
-    "sum": lambda x: models.Sum(Cast(x, output_field=models.IntegerField())),
-    "variance": models.Variance,
-}
-
-
-_AGGREGATES = {
-    # NTS beware that Sum(type) -> type
+_TYPE_AGGREGATES = {
     StringType: ["count"],
     NumberType: ["average", "count", "max", "min", "std_dev", "sum", "variance"],
     DateTimeType: ["count"],  # average, min and max might be nice here but sqlite
@@ -44,20 +39,7 @@ _AGGREGATES = {
     BooleanType: ["average", "sum"],
 }
 
-
-_FUNC_MAP = {
-    "year": (functions.ExtractYear, YearType),
-    "quarter": (functions.ExtractQuarter, NumberType),
-    "month": (functions.ExtractMonth, MonthType),
-    "day": (functions.ExtractDay, NumberType),
-    "week_day": (functions.ExtractWeekDay, WeekDayType),
-    "hour": (functions.ExtractHour, NumberType),
-    "minute": (functions.ExtractMinute, NumberType),
-    "second": (functions.ExtractSecond, NumberType),
-    "date": (functions.TruncDate, DateType),
-}
-
-_FUNCTIONS = {
+_TYPE_FUNCTIONS = {
     DateTimeType: [
         "year",
         "quarter",
@@ -70,9 +52,83 @@ _FUNCTIONS = {
         "date",
     ],
     DateType: ["year", "quarter", "month", "day", "week_day"],
+    None: ["is_null"],  # all fields
 }
 
 
+def _get_django_aggregate(field_type, name):
+    if field_type == BooleanType:
+        return {
+            "average": lambda x: models.Avg(Cast(x, output_field=IntegerField())),
+            "sum": lambda x: models.Sum(Cast(x, output_field=IntegerField())),
+        }[name]
+    else:
+        return {
+            # these all have result type number
+            "average": models.Avg,
+            "count": lambda x: models.Count(x, distinct=True),
+            "max": models.Max,
+            "min": models.Min,
+            "std_dev": models.StdDev,
+            "sum": models.Sum,
+            "variance": models.Variance,
+        }[name]
+
+
+def _get_django_lookup(field_type, lookup, filter_value):
+    from .types import StringChoiceType, StringType
+
+    if lookup == "field_equals":
+        lookup, filter_value = filter_value
+        return lookup, filter_value
+    elif field_type in [StringType, StringChoiceType]:
+        return (
+            {
+                "equals": "iexact",
+                "regex": "iregex",
+                "contains": "icontains",
+                "starts_with": "istartswith",
+                "ends_with": "iendswith",
+                "is_null": "isnull",
+            }[lookup],
+            filter_value,
+        )
+    else:
+        return (
+            {
+                "equals": "exact",
+                "is_null": "isnull",
+                "gt": "gt",
+                "gte": "gte",
+                "lt": "lt",
+                "lte": "lte",
+                "contains": "contains",
+                "length": "len",
+                "has_key": "has_key",
+            }[lookup],
+            filter_value,
+        )
+
+
+def IsNull(field_name):
+    return ExpressionWrapper(Q(**{field_name: None}), output_field=BooleanField())
+
+
+def _get_django_function(name):
+    return {
+        "year": (functions.ExtractYear, YearType),
+        "quarter": (functions.ExtractQuarter, NumberType),
+        "month": (functions.ExtractMonth, MonthType),
+        "day": (functions.ExtractDay, NumberType),
+        "week_day": (functions.ExtractWeekDay, WeekDayType),
+        "hour": (functions.ExtractHour, NumberType),
+        "minute": (functions.ExtractMinute, NumberType),
+        "second": (functions.ExtractSecond, NumberType),
+        "date": (functions.TruncDate, DateType),
+        "is_null": (IsNull, BooleanType),
+    }[name]
+
+
 def s(path):
     return "__".join(path)
 
@@ -81,6 +137,17 @@ def get_model_name(model, sep="."):
     return f"{model._meta.app_label}{sep}{model.__name__}"
 
 
+def get_fields_for_type(type_):
+    aggregates = {
+        a: OrmAggregateField(type_.name, a) for a in _TYPE_AGGREGATES.get(type_, [])
+    }
+    functions = {
+        f: OrmFunctionField(type_.name, f, _get_django_function(f)[1])
+        for f in _TYPE_FUNCTIONS[None] + _TYPE_FUNCTIONS.get(type_, [])
+    }
+    return {**aggregates, **functions}
+
+
 @dataclass
 class OrmBoundField:
     field: "OrmBaseField"
@@ -160,16 +227,14 @@ class OrmFkField(OrmBaseField):
 
 
 class OrmConcreteField(OrmBaseField):
-    def __init__(self, model_name, name, pretty_name, type_, choices=None):
+    def __init__(self, model_name, name, pretty_name, type_, rel_name, choices=None):
         super().__init__(
             model_name,
             name,
             pretty_name,
             concrete=True,
             type_=type_,
-            rel_name=(
-                type_.name if type_ in _AGGREGATES or type_ in _FUNCTIONS else None
-            ),
+            rel_name=rel_name,
             can_pivot=True,
             choices=choices or (),
         )
@@ -227,7 +292,7 @@ class OrmCalculatedField(OrmBaseField):
 
 class OrmBoundAnnotatedField(OrmBoundField):
     def annotate(self, request, qs):
-        from .orm import admin_get_queryset
+        from .orm_results import admin_get_queryset
 
         return qs.annotate(
             **{
@@ -283,7 +348,7 @@ class OrmAnnotatedField(OrmBaseField):
 class OrmAdminField(OrmBaseField):
     def __init__(self, model_name):
         super().__init__(
-            model_name, _OPEN_IN_ADMIN, _OPEN_IN_ADMIN, type_=HTMLType, can_pivot=True
+            model_name, OPEN_IN_ADMIN, OPEN_IN_ADMIN, type_=HTMLType, can_pivot=True
         )
 
     def bind(self, previous):
@@ -310,7 +375,9 @@ class OrmAdminField(OrmBaseField):
 
 class OrmFileField(OrmConcreteField):
     def __init__(self, model_name, name, pretty_name, django_field):
-        super().__init__(model_name, name, pretty_name, type_=HTMLType)
+        super().__init__(
+            model_name, name, pretty_name, type_=HTMLType, rel_name=HTMLType.name
+        )
         self.django_field = django_field
 
     def format(self, value):
@@ -329,32 +396,26 @@ class OrmFileField(OrmConcreteField):
 class OrmAggregateField(OrmBaseField):
     def __init__(self, model_name, name):
         super().__init__(model_name, name, name, type_=NumberType, concrete=True)
-        self.aggregate = name
 
     def bind(self, previous):
         assert previous
         full_path = previous.full_path + [self.name]
-        agg = _AGG_MAP[self.aggregate](s(previous.full_path))
+        agg_func = _get_django_aggregate(previous.type_, self.name)
         return OrmBoundField(
             field=self,
             previous=previous,
             full_path=full_path,
             pretty_path=previous.pretty_path + [self.pretty_name],
             queryset_path=s(full_path),
-            aggregate_clause=(s(full_path), agg),
+            aggregate_clause=(s(full_path), agg_func(s(previous.full_path))),
             having=True,
         )
 
 
 class OrmBoundFunctionField(OrmBoundField):
     def annotate(self, request, qs):
-        return qs.annotate(
-            **{
-                self.queryset_path: _FUNC_MAP[self.function][0](
-                    s(self.previous.full_path)
-                )
-            }
-        )
+        func = _get_django_function(self.name)[0](s(self.previous.full_path))
+        return qs.annotate(**{self.queryset_path: func})
 
 
 class OrmFunctionField(OrmBaseField):
@@ -362,7 +423,6 @@ class OrmFunctionField(OrmBaseField):
         super().__init__(
             model_name, name, name, type_=type_, concrete=True, can_pivot=True
         )
-        self.function = name
 
     def bind(self, previous):
         assert previous
