@@ -17,8 +17,11 @@ from django.views.decorators import csrf
 from . import version
 from .common import HttpResponse, JsonResponse, can_make_public, settings
 from .models import View
-from .orm import _OPEN_IN_ADMIN, get_models, get_results
-from .query import TYPES, BoundQuery, Query
+from .orm_admin import get_models
+from .orm_fields import OPEN_IN_ADMIN
+from .orm_results import get_results
+from .query import BoundQuery, Query
+from .types import TYPES
 
 
 def _get_query_data(bound_query):
@@ -52,9 +55,8 @@ def _get_query_data(bound_query):
 
 def _get_model_fields(orm_model):
     def sort_model_fields(fields):
-        fields = sorted(fields)
-        front = {"id": 1, _OPEN_IN_ADMIN: 2}
-        return sorted(fields, key=lambda x: front.get(x, sys.maxsize))
+        front = {"id": 1, OPEN_IN_ADMIN: 2}
+        return sorted(fields, key=lambda f: (front.get(f, sys.maxsize), f))
 
     all_fields = {
         name: {
