@@ -1,21 +1,33 @@
 import dj_database_url
+import django
+import pytest
 from django.conf import settings
 
+DATABASE_CONFIG = dj_database_url.config(
+    conn_max_age=600, default="sqlite:///db.sqlite3"
+)
+
+if DATABASE_CONFIG["ENGINE"] == "django.db.backends.postgresql":  # pragma: postgres
+    JSON_FIELD_SUPPORT = django.VERSION > (2, 1)
+else:
+    JSON_FIELD_SUPPORT = django.VERSION > (3, 1)
+
+INSTALLED_APPS = [
+    "django.contrib.auth",
+    "django.contrib.contenttypes",
+    "django.contrib.sessions",
+    "django.contrib.staticfiles",
+    "django.contrib.admin",
+    "tests.core",
+    "data_browser",
+]
+
+if JSON_FIELD_SUPPORT:  # pragma: no branch
+    INSTALLED_APPS.append("tests.json")
+
 settings.configure(
-    INSTALLED_APPS=[
-        "django.contrib.auth",
-        "django.contrib.contenttypes",
-        "django.contrib.sessions",
-        "django.contrib.staticfiles",
-        "django.contrib.admin",
-        "tests",
-        "data_browser",
-    ],
-    DATABASES={
-        "default": dj_database_url.config(
-            conn_max_age=600, default="sqlite:///db.sqlite3"
-        )
-    },
+    INSTALLED_APPS=INSTALLED_APPS,
+    DATABASES={"default": DATABASE_CONFIG},
     ROOT_URLCONF="tests.urls",
     MIDDLEWARE=[
         "django.middleware.security.SecurityMiddleware",
@@ -43,3 +55,10 @@ settings.configure(
     DATA_BROWSER_ALLOW_PUBLIC=True,
     USE_I18N=True,
 )
+
+
+@pytest.fixture
+def req(rf, admin_user):
+    req = rf.get("/")
+    req.user = admin_user
+    return req
