@@ -5,11 +5,12 @@ from django.contrib.admin.options import BaseModelAdmin
 from django.contrib.auth.models import Permission, User
 from django.utils import timezone
 
-from data_browser import orm, orm_fields
-from data_browser.orm import admin_get_queryset
+from data_browser import orm_fields
+from data_browser.orm_admin import get_models
+from data_browser.orm_results import admin_get_queryset, get_results
 from data_browser.query import BoundQuery, Query
 
-from . import models
+from .core import models
 from .util import ANY, KEYS
 
 
@@ -19,7 +20,7 @@ def sortedAssert(a, b):
 
 def admin_link(obj):
     model = obj.__class__.__name__.lower()
-    return f'<a href="/admin/tests/{model}/{obj.pk}/change/">{obj}</a>'
+    return f'<a href="/admin/core/{model}/{obj.pk}/change/">{obj}</a>'
 
 
 def flatten_table(fields, data):
@@ -41,6 +42,7 @@ def products(db):
             size_unit="g",
             producer=producer,
             fake="phoney",
+            boat=2.2,
         )
     )
 
@@ -55,7 +57,12 @@ def products(db):
     producer = models.Producer.objects.create(name="Bob", address=None)
     res.append(
         models.Product.objects.create(
-            created_time=now, name="c", size=2, size_unit="g", producer=producer
+            created_time=now,
+            name="c",
+            size=2,
+            size_unit="g",
+            producer=producer,
+            boat=2.4,
         )
     )
 
@@ -93,16 +100,16 @@ def req(rf, admin_user):
 
 @pytest.fixture
 def orm_models(req):
-    return orm.get_models(req)
+    return get_models(req)
 
 
 @pytest.fixture
 def get_product_flat(req, orm_models, django_assert_num_queries):
     def helper(queries, *args, **kwargs):
-        query = Query.from_request("tests.Product", *args)
+        query = Query.from_request("core.Product", *args, **kwargs)
         bound_query = BoundQuery.bind(query, orm_models)
         with django_assert_num_queries(queries):
-            data = orm.get_results(req, bound_query, orm_models)
+            data = get_results(req, bound_query, orm_models)
             return flatten_table(bound_query.fields, data["rows"])
 
     return helper
@@ -111,10 +118,10 @@ def get_product_flat(req, orm_models, django_assert_num_queries):
 @pytest.fixture
 def get_product_pivot(req, orm_models, django_assert_num_queries):
     def helper(queries, *args, **kwargs):
-        query = Query.from_request("tests.Product", *args)
+        query = Query.from_request("core.Product", *args, **kwargs)
         bound_query = BoundQuery.bind(query, orm_models)
         with django_assert_num_queries(queries):
-            data = orm.get_results(req, bound_query, orm_models)
+            data = get_results(req, bound_query, orm_models)
             return {
                 "cols": flatten_table(bound_query.col_fields, data["cols"]),
                 "rows": flatten_table(bound_query.row_fields, data["rows"]),
@@ -170,12 +177,12 @@ def test_bad_storage(monkeypatch, req):
     default_storage._wrapped = empty
 
     # copy what the fixture does
-    orm_models = orm.get_models(req)
+    orm_models = get_models(req)
 
     def get_product_flat(*args, **kwargs):
-        query = Query.from_request("tests.Product", *args)
+        query = Query.from_request("core.Product", *args)
         bound_query = BoundQuery.bind(query, orm_models)
-        data = orm.get_results(req, bound_query, orm_models)
+        data = get_results(req, bound_query, orm_models)
         return flatten_table(bound_query.fields, data["rows"])
 
     # some storage backends will hard fail if their underlying storage isn't
@@ -194,14 +201,18 @@ def test_get_calculated_field_on_admin(get_product_flat):
 
 
 def test_get_annotated_field_at_base(products, get_product_flat, mocker):
-    mock = mocker.patch("data_browser.orm.admin_get_queryset", wraps=admin_get_queryset)
+    mock = mocker.patch(
+        "data_browser.orm_results.admin_get_queryset", wraps=admin_get_queryset
+    )
     data = get_product_flat(1, "annotated+1,size-2", {"annotated__not_equals": ["a"]})
     assert data == [["b", 1], ["c", 2]]
     assert len(mock.call_args_list) == 2
 
 
 def test_get_annotated_field_down_tree(products, get_product_flat, mocker):
-    mock = mocker.patch("data_browser.orm.admin_get_queryset", wraps=admin_get_queryset)
+    mock = mocker.patch(
+        "data_browser.orm_results.admin_get_queryset", wraps=admin_get_queryset
+    )
     data = get_product_flat(
         1,
         "producer__address__andrew+1,size-2",
@@ -229,12 +240,30 @@ def test_get_property(get_product_flat):
     sortedAssert(data, [[None], ["bad"], ["tom"]])
 
 
+@pytest.mark.usefixtures("products")
+def test_get_float_average(get_product_flat):
+    data = get_product_flat(1, "boat__average", {})
+    sortedAssert(data, [[2.3]])
+
+
+@pytest.mark.usefixtures("products")
+def test_get_float_sum(get_product_flat):
+    data = get_product_flat(1, "boat__sum", {})
+    sortedAssert(data, [[4.6]])
+
+
 @pytest.mark.usefixtures("products")
 def test_get_time_function(get_product_flat):
     data = get_product_flat(1, "created_time__year", {})
     assert data == [[timezone.now().year]]
 
 
+@pytest.mark.usefixtures("products")
+def test_get_is_null_function(get_product_flat):
+    data = get_product_flat(1, "name+0,producer__address__city__is_null", {})
+    assert data == [["a", False], ["b", False], ["c", True]]
+
+
 @pytest.mark.usefixtures("products")
 def test_get_aggregate(get_product_flat):
     data = get_product_flat(1, "size_unit,id__count", {})
@@ -580,7 +609,7 @@ def test_get_pivot_permutations(get_product_pivot, key, rows, cols, body):
     if "b" in key:  # fields in the body
         fields.extend(["size__count", "size__max"])
     if "d" not in key:  # actually has data
-        filters["id__equals"] = ["123"]
+        filters["id__equals"] = ["-1"]
 
     queries = 0 if key.endswith("---") else 1
     if "r" in key and "c" in key:
@@ -595,14 +624,14 @@ def test_get_pivot_permutations(get_product_pivot, key, rows, cols, body):
 def test_get_fields(orm_models):
 
     # remap pk to id
-    assert "pk" not in orm_models["tests.Product"].fields
-    assert "id" in orm_models["tests.Product"].fields
+    assert "pk" not in orm_models["core.Product"].fields
+    assert "id" in orm_models["core.Product"].fields
 
     # no many to many fields
-    assert "tags" not in orm_models["tests.Product"].fields
+    assert "tags" not in orm_models["core.Product"].fields
 
     # no admin on inlines
-    assert "admin" not in orm_models["tests.InlineAdmin"].fields
+    assert "admin" not in orm_models["core.InlineAdmin"].fields
 
 
 class TestPermissions:
@@ -613,21 +642,21 @@ class TestPermissions:
 
         request = rf.get("/")
         request.user = user
-        return orm.get_models(request)
+        return get_models(request)
 
     def test_all_perms(self, rf, admin_user):
         orm_models = self.get_fields_with_perms(
             rf, ["normal", "notinadmin", "inadmin", "inlineadmin"]
         )
 
-        assert "tests.NotInAdmin" not in orm_models
-        assert orm_models["tests.InAdmin"] == orm_fields.OrmModel(
+        assert "core.NotInAdmin" not in orm_models
+        assert orm_models["core.InAdmin"] == orm_fields.OrmModel(
             fields=KEYS("admin", "id", "name"), admin=ANY(BaseModelAdmin)
         )
-        assert orm_models["tests.InlineAdmin"] == orm_fields.OrmModel(
+        assert orm_models["core.InlineAdmin"] == orm_fields.OrmModel(
             fields=KEYS("id", "name", "in_admin"), admin=ANY(BaseModelAdmin)
         )
-        assert orm_models["tests.Normal"] == orm_fields.OrmModel(
+        assert orm_models["core.Normal"] == orm_fields.OrmModel(
             fields=KEYS("admin", "id", "name", "in_admin", "inline_admin"),
             admin=ANY(BaseModelAdmin),
         )
@@ -636,10 +665,10 @@ class TestPermissions:
     def test_no_perms(self, rf):
         orm_models = self.get_fields_with_perms(rf, ["normal"])
 
-        assert "tests.NotInAdmin" not in orm_models
-        assert "tests.InAdmin" not in orm_models
-        assert "tests.InlineAdmin" not in orm_models
-        assert orm_models["tests.Normal"] == orm_fields.OrmModel(
+        assert "core.NotInAdmin" not in orm_models
+        assert "core.InAdmin" not in orm_models
+        assert "core.InlineAdmin" not in orm_models
+        assert orm_models["core.Normal"] == orm_fields.OrmModel(
             fields=KEYS("admin", "id", "name"), admin=ANY(BaseModelAdmin)
         )
 
@@ -647,10 +676,10 @@ class TestPermissions:
     def test_inline_perms(self, rf):
         orm_models = self.get_fields_with_perms(rf, ["normal", "inlineadmin"])
 
-        assert "tests.NotInAdmin" not in orm_models
-        assert "tests.InAdmin" not in orm_models
-        assert "tests.InlineAdmin" not in orm_models
-        assert orm_models["tests.Normal"] == orm_fields.OrmModel(
+        assert "core.NotInAdmin" not in orm_models
+        assert "core.InAdmin" not in orm_models
+        assert "core.InlineAdmin" not in orm_models
+        assert orm_models["core.Normal"] == orm_fields.OrmModel(
             fields=KEYS("admin", "id", "name"), admin=ANY(BaseModelAdmin)
         )
 
@@ -658,11 +687,11 @@ class TestPermissions:
     def test_admin_perms(self, rf):
         orm_models = self.get_fields_with_perms(rf, ["normal", "inadmin"])
 
-        assert "tests.NotInAdmin" not in orm_models
-        assert orm_models["tests.InAdmin"] == orm_fields.OrmModel(
+        assert "core.NotInAdmin" not in orm_models
+        assert orm_models["core.InAdmin"] == orm_fields.OrmModel(
             fields=KEYS("admin", "id", "name"), admin=ANY(BaseModelAdmin)
         )
-        assert "tests.InlineAdmin" not in orm_models
-        assert orm_models["tests.Normal"] == orm_fields.OrmModel(
+        assert "core.InlineAdmin" not in orm_models
+        assert orm_models["core.Normal"] == orm_fields.OrmModel(
             fields=KEYS("admin", "id", "name", "in_admin"), admin=ANY(BaseModelAdmin)
         )
